@@ -52,6 +52,13 @@ ConfigDialog::ConfigDialog(QWidget* parent)
 
     // General
     widget = setupPage(mGeneralConfigPage);
+    
+    mThumbnailActionsGroup = new InvisibleButtonGroup(widget);
+    mThumbnailActionsGroup->setObjectName(QLatin1String("kcfg_ThumbnailActions"));
+    mThumbnailActionsGroup->addButton(mGeneralConfigPage.allButtonsThumbnailActionsRadioButton, int(ThumbnailActions::AllButtons));
+    mThumbnailActionsGroup->addButton(mGeneralConfigPage.selectionOnlyThumbnailActionsRadioButton, int(ThumbnailActions::ShowSelectionButtonOnly));
+    mThumbnailActionsGroup->addButton(mGeneralConfigPage.noneThumbnailActionsRadioButton, int(ThumbnailActions::None));
+
     pageItem = addPage(widget, i18n("General"));
     pageItem->setIcon(QIcon::fromTheme("gwenview"));
     connect(mGeneralConfigPage.kcfg_ViewBackgroundValue, SIGNAL(valueChanged(int)), SLOT(updateViewBackgroundFrame()));
@@ -91,9 +98,17 @@ ConfigDialog::ConfigDialog(QWidget* parent)
 
     // Advanced
     widget = setupPage(mAdvancedConfigPage);
+
+    mRenderingIntentGroup = new InvisibleButtonGroup(widget);
+    mRenderingIntentGroup->setObjectName(QLatin1String("kcfg_RenderingIntent"));
+    mRenderingIntentGroup->addButton(mAdvancedConfigPage.relativeRenderingIntentRadioButton, int(RenderingIntent::Relative));
+    mRenderingIntentGroup->addButton(mAdvancedConfigPage.perceptualRenderingIntentRadioButton, int(RenderingIntent::Perceptual));
+
     pageItem = addPage(widget, i18n("Advanced"));
     pageItem->setIcon(QIcon::fromTheme("preferences-other"));
     mAdvancedConfigPage.cacheHelpLabel->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
+    mAdvancedConfigPage.perceptualHelpLabel->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
+    mAdvancedConfigPage.relativeHelpLabel->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
 
     updateViewBackgroundFrame();
 }
