@@ -47,6 +47,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <lib/thumbnailview/thumbnailbarview.h>
 #include <lib/shadowfilter.h>
 #include <lib/slideshow.h>
+#include <gvcore.h>
+#include <lib/stylesheetutils.h>
 
 namespace Gwenview
 {
@@ -99,10 +101,10 @@ private:
 };
 
 
-FullScreenContent::FullScreenContent(QObject* parent)
+FullScreenContent::FullScreenContent(QObject* parent, GvCore* gvCore)
 : QObject(parent)
 {
-    mFullScreenMode = false;
+    mGvCore = gvCore;
     mViewPageVisible = false;
 }
 
@@ -127,7 +129,6 @@ void FullScreenContent::init(KActionCollection* actionCollection, QWidget* autoH
     mContent->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     mContent->setAutoFillBackground(true);
     EventWatcher::install(mContent, QEvent::Show, this, SLOT(updateCurrentUrlWidgets()));
-    EventWatcher::install(mContent, QEvent::PaletteChange, this, SLOT(slotPaletteChanged()));
     layout->addWidget(mContent);
 
     createOptionsAction();
@@ -152,8 +153,9 @@ void FullScreenContent::init(KActionCollection* actionCollection, QWidget* autoH
     mInformationLabel = new QLabel;
     mInformationLabel->setWordWrap(true);
     mInformationLabel->setContentsMargins(6, 0, 6, 0);
-    mInformationLabel->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Expanding);
+    mInformationLabel->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
     mInformationLabel->setAutoFillBackground(true);
+    mInformationLabel->setBackgroundRole(QPalette::Mid);
     mInformationLabelShadow = new ShadowFilter(mInformationLabel);
 
     // Thumbnail bar
@@ -217,13 +219,6 @@ void FullScreenContent::updateInformationLabel()
     mInformationLabel->setText(text);
 }
 
-void FullScreenContent::slotPaletteChanged()
-{
-    QPalette pal = mContent->palette();
-    pal.setColor(QPalette::Window, pal.color(QPalette::Window).dark(110));
-    mInformationLabel->setPalette(pal);
-}
-
 void FullScreenContent::updateCurrentUrlWidgets()
 {
     updateInformationLabel();
@@ -324,7 +319,7 @@ void FullScreenContent::updateLayout()
         layout->addWidget(mInformationLabel);
         layout->addWidget(mRightToolBar);
 
-        mAutoHideContainer->setFixedHeight(mContent->sizeHint().height());
+        mAutoHideContainer->setFixedHeight(mToolBar->sizeHint().height());
 
         // Shadows
         mToolBarShadow->reset();
@@ -341,7 +336,7 @@ void FullScreenContent::updateLayout()
 
 void FullScreenContent::updateContainerAppearance()
 {
-    if (!mFullScreenMode || !mViewPageVisible) {
+    if (!mContent->window()->isFullScreen() || !mViewPageVisible) {
         mAutoHideContainer->setActivated(false);
         return;
     }
@@ -353,7 +348,7 @@ void FullScreenContent::updateContainerAppearance()
 
 void FullScreenContent::adjustSize()
 {
-    if (mFullScreenMode && mViewPageVisible) {
+    if (mContent->window()->isFullScreen() && mViewPageVisible) {
         mAutoHideContainer->adjustSize();
     }
 }
@@ -460,8 +455,9 @@ void FullScreenContent::showOptionsMenu()
 
 void FullScreenContent::setFullScreenMode(bool fullScreenMode)
 {
-    mFullScreenMode = fullScreenMode;
+    Q_UNUSED(fullScreenMode);
     updateContainerAppearance();
+    setupThumbnailBarStyleSheet();
 }
 
 void FullScreenContent::setDistractionFreeMode(bool distractionFreeMode)
@@ -490,4 +486,40 @@ void FullScreenContent::slotViewModeActionToggled(bool value)
     updateContainerAppearance();
 }
 
+void FullScreenContent::setupThumbnailBarStyleSheet()
+{
+    const QPalette pal = mGvCore->palette(GvCore::NormalPalette);
+    const QPalette fsPal = mGvCore->palette(GvCore::FullScreenPalette);
+    QColor bgColor = fsPal.color(QPalette::Normal, QPalette::Base);
+    QColor bgSelColor = pal.color(QPalette::Normal, QPalette::Highlight);
+    QColor bgHovColor = pal.color(QPalette::Normal, QPalette::Highlight);
+    
+    // Darken the select color a little to suit dark theme of fullscreen mode
+    bgSelColor.setHsv(bgSelColor.hue(), bgSelColor.saturation(), (bgSelColor.value() * 0.8));
+    
+    // Calculate hover color based on background color in case it changes (matches ViewMainPage thumbnail bar)
+    bgHovColor.setHsv(bgHovColor.hue(), (bgHovColor.saturation() / 2), ((bgHovColor.value() + bgColor.value()) / 2));
+    
+    QString genCss = 
+        "QListView {"
+        "  background-color: %1;"
+        "}";
+    genCss = genCss.arg(StyleSheetUtils::rgba(bgColor));
+    
+    QString itemSelCss = 
+        "QListView::item:selected {"
+        "  background-color: %1;"
+        "}";
+    itemSelCss = itemSelCss.arg(StyleSheetUtils::rgba(bgSelColor));
+    
+    QString itemHovCss = 
+        "QListView::item:hover:!selected {"
+        "  background-color: %1;"
+        "}";
+    itemHovCss = itemHovCss.arg(StyleSheetUtils::rgba(bgHovColor));
+    
+    QString css = genCss + itemSelCss + itemHovCss;
+    mThumbnailBar->setStyleSheet(css);
+}
+
 } // namespace
