@@ -18,10 +18,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 #include <config-gwenview.h>
-// STL
-#include <memory>
 
 // Qt
+#include <QPointer>
 #include <QScopedPointer>
 #include <QUrl>
 #include <QTemporaryDir>
@@ -38,6 +37,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 // Local
 #include <lib/about.h>
 #include <lib/imageformats/imageformats.h>
+#include <lib/gwenviewconfig.h>
 #include "mainwindow.h"
 
 #ifdef HAVE_FITS
@@ -91,22 +91,22 @@ public:
 
     void createMainWindow()
     {
-        Gwenview::MainWindow* window = new Gwenview::MainWindow();
+        mMainWindow = new Gwenview::MainWindow();
         if (mUrl.isValid()) {
-            window->setInitialUrl(mUrl);
+            mMainWindow->setInitialUrl(mUrl);
         } else {
-            window->showStartMainPage();
+            mMainWindow->showStartMainPage();
         }
 
-        window->show();
+        mMainWindow->show();
         if (mFullScreen) {
-            window->actionCollection()->action("fullscreen")->trigger();
+            mMainWindow->actionCollection()->action("fullscreen")->trigger();
         } else {
-            window->show();
+            mMainWindow->show();
         }
 
         if (mSlideShow) {
-            window->startSlideShow();
+            mMainWindow->startSlideShow();
         }
     }
 
@@ -114,8 +114,8 @@ private:
     QUrl mUrl;
     bool mFullScreen;
     bool mSlideShow;
-    std::unique_ptr<QTemporaryDir> mMultipleUrlsDir;
-    std::unique_ptr<Gwenview::MainWindow> mMainWindow;
+    QScopedPointer<QTemporaryDir> mMultipleUrlsDir;
+    QPointer<Gwenview::MainWindow> mMainWindow;
 };
 
 int main(int argc, char *argv[])
@@ -140,8 +140,6 @@ int main(int argc, char *argv[])
                                         i18n("Start in fullscreen mode")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("s") << QStringLiteral("slideshow"),
                                         i18n("Start in slideshow mode")));
-    parser.addHelpOption();
-    parser.addVersionOption();
     parser.addPositionalArgument("url", i18n("A starting file or folders"));
     parser.process(app);
     aboutData.data()->processCommandLine(&parser);
@@ -151,7 +149,9 @@ int main(int argc, char *argv[])
 
     // startHelper must live for the whole life of the application
     StartHelper startHelper(parser.positionalArguments(),
-                            parser.isSet(QStringLiteral("f")),
+                            parser.isSet(QStringLiteral("f"))
+                                ? true
+                                : Gwenview::GwenviewConfig::fullScreenModeActive(),
                             parser.isSet(QStringLiteral("s")));
     if (app.isSessionRestored()) {
         kRestoreMainWindows<Gwenview::MainWindow>();
