@@ -478,8 +478,8 @@ struct MainWindow::Private
 
         actionCollection->setDefaultShortcut(mShowStatusBarAction, Qt::Key_F3);
 
-        view->addAction(KStandardAction::KeyBindings, q->guiFactory(),
-                        SLOT(configureShortcuts()));
+        view->addAction(KStandardAction::name(KStandardAction::KeyBindings),
+                        KStandardAction::keyBindings(q, &MainWindow::configureShortcuts, actionCollection));
 
         view->addAction(KStandardAction::Preferences, q,
                         SLOT(showConfigDialog()));
@@ -1488,6 +1488,12 @@ void MainWindow::showConfigDialog()
     dialog->exec();
 }
 
+void MainWindow::configureShortcuts()
+{
+    guiFactory()->configureShortcuts();
+    guiFactory()->refreshActionProperties();
+}
+
 void MainWindow::toggleMenuBar()
 {
     if (!d->mFullScreenAction->isChecked()) {
