@@ -43,7 +43,7 @@ public:
         : mRect(rect)
     {}
 
-    virtual void threadedStart()
+    void threadedStart() Q_DECL_OVERRIDE
     {
         if (!checkDocumentEditor()) {
             return;
@@ -89,6 +89,7 @@ void CropImageOperation::undo()
         return;
     }
     document()->editor()->setImage(d->mOriginalImage);
+    finishUndoJob();
 }
 
 } // namespace
