@@ -53,14 +53,20 @@ public:
 
     bool zoomToFit() const;
 
+    bool zoomToFill() const;
+
     virtual void setZoomToFit(bool value);
 
+    virtual void setZoomToFill(bool value);
+
     virtual void setDocument(Document::Ptr doc);
 
     Document::Ptr document() const;
 
     qreal computeZoomToFit() const;
 
+    qreal computeZoomToFill() const;
+
     QSizeF documentSize() const;
 
     QSizeF visibleImageSize() const;
@@ -98,6 +104,7 @@ public Q_SLOTS:
 
 Q_SIGNALS:
     void zoomToFitChanged(bool);
+    void zoomToFillChanged(bool);
     void zoomChanged(qreal);
     void zoomInRequested(const QPointF&);
     void zoomOutRequested(const QPointF&);
