@@ -56,9 +56,7 @@ public:
     {
         mLayout->setMargin(0);
         setAutoFillBackground(true);
-        QPalette pal = palette();
-        pal.setColor(QPalette::Window, pal.color(QPalette::Window).dark(120));
-        setPalette(pal);
+        setBackgroundRole(QPalette::Mid);
     }
 
     void setToolWidget(QWidget* widget)
@@ -81,6 +79,7 @@ struct DocumentViewControllerPrivate
     ToolContainerContent* mToolContainerContent;
 
     QAction * mZoomToFitAction;
+    QAction * mZoomToFillAction;
     QAction * mActualSizeAction;
     QAction * mZoomInAction;
     QAction * mZoomOutAction;
@@ -94,18 +93,28 @@ struct DocumentViewControllerPrivate
         view->collection()->setDefaultShortcut(mZoomToFitAction, Qt::Key_F);
         mZoomToFitAction->setCheckable(true);
         mZoomToFitAction->setChecked(true);
-        mZoomToFitAction->setText(i18n("Zoom to Fit"));
+        mZoomToFitAction->setText(i18n("Zoom to fit"));
         mZoomToFitAction->setIcon(QIcon::fromTheme("zoom-fit-best"));
         mZoomToFitAction->setIconText(i18nc("@action:button Zoom to fit, shown in status bar, keep it short please", "Fit"));
 
+        mZoomToFillAction = view->addAction("view_zoom_to_fill");
+        //view->collection()->setDefaultShortcuts(mZoomToFillAction, Qt::Key_W); ??
+        mZoomToFillAction->setCheckable(true);
+        mZoomToFillAction->setChecked(false);
+        mZoomToFillAction->setText(i18n("Zoom to fill window by fitting to width or height"));
+        mZoomToFillAction->setIcon(QIcon::fromTheme("zoom-fit-best"));
+        mZoomToFillAction->setIconText(i18nc("@action:button Zoom to fill (fit width or height), shown in status bar, keep it short please", "Fill"));
+
         mActualSizeAction = view->addAction(KStandardAction::ActualSize);
+        mActualSizeAction->setCheckable(true);
+        mZoomToFillAction->setChecked(false);
         mActualSizeAction->setIcon(QIcon::fromTheme("zoom-original"));
         mActualSizeAction->setIconText(i18nc("@action:button Zoom to original size, shown in status bar, keep it short please", "100%"));
 
         mZoomInAction = view->addAction(KStandardAction::ZoomIn);
         mZoomOutAction = view->addAction(KStandardAction::ZoomOut);
 
-        mActions << mZoomToFitAction << mActualSizeAction << mZoomInAction << mZoomOutAction;
+        mActions << mZoomToFitAction << mActualSizeAction << mZoomInAction << mZoomOutAction << mZoomToFillAction;
     }
 
     void connectZoomWidget()
@@ -177,10 +186,13 @@ void DocumentViewController::setView(DocumentView* view)
     }
     connect(d->mView, &DocumentView::adapterChanged, this, &DocumentViewController::slotAdapterChanged);
     connect(d->mView, &DocumentView::zoomToFitChanged, this, &DocumentViewController::updateZoomToFitActionFromView);
+    connect(d->mView, &DocumentView::zoomToFillChanged, this, &DocumentViewController::updateZoomToFillActionFromView);
     connect(d->mView, &DocumentView::currentToolChanged, this, &DocumentViewController::updateTool);
 
     connect(d->mZoomToFitAction, SIGNAL(toggled(bool)),
             d->mView, SLOT(setZoomToFit(bool)));
+    connect(d->mZoomToFillAction, SIGNAL(toggled(bool)),
+            d->mView, SLOT(setZoomToFill(bool)));
     connect(d->mActualSizeAction, SIGNAL(triggered()),
             d->mView, SLOT(zoomActualSize()));
     connect(d->mZoomInAction, SIGNAL(triggered()),
@@ -190,6 +202,7 @@ void DocumentViewController::setView(DocumentView* view)
 
     d->updateActions();
     updateZoomToFitActionFromView();
+    updateZoomToFillActionFromView();
     updateTool();
 
     // Sync zoom widget
@@ -210,7 +223,8 @@ void DocumentViewController::setZoomWidget(ZoomWidget* widget)
         d->mZoomToFitAction,
         d->mActualSizeAction,
         d->mZoomInAction,
-        d->mZoomOutAction
+        d->mZoomOutAction,
+        d->mZoomToFillAction
     );
 
     d->mZoomWidget->setMaximumZoom(qreal(DocumentView::MaximumZoom));
@@ -236,6 +250,12 @@ void DocumentViewController::updateZoomToFitActionFromView()
     d->mZoomToFitAction->setChecked(d->mView->zoomToFit());
 }
 
+void DocumentViewController::updateZoomToFillActionFromView()
+{
+    SignalBlocker blocker(d->mZoomToFillAction);
+    d->mZoomToFillAction->setChecked(d->mView->zoomToFill());
+}
+
 void DocumentViewController::updateTool()
 {
     if (!d->mToolContainer) {
