@@ -24,9 +24,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 // Qt
 #include <QObject>
+#include <QUrl>
 
 // KDE
-#include <KUrl>
 
 // Local
 
@@ -45,9 +45,9 @@ public:
 
     virtual void showContextMenu(QWidget* parent) = 0;
 
-    virtual void showMenuForUrlDroppedOnViewport(QWidget* parent, const KUrl::List&) = 0;
+    virtual void showMenuForUrlDroppedOnViewport(QWidget* parent, const QList<QUrl>&) = 0;
 
-    virtual void showMenuForUrlDroppedOnDir(QWidget* parent, const KUrl::List&, const KUrl&) = 0;
+    virtual void showMenuForUrlDroppedOnDir(QWidget* parent, const QList<QUrl>&, const QUrl&) = 0;
 };
 
 } // namespace
