@@ -17,13 +17,13 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
-#include <qtest_kde.h>
+#include <qtest.h>
 
 #include "../lib/paintutils.h"
 
-#include "paintutilstest.moc"
+#include "paintutilstest.h"
 
-QTEST_KDEMAIN(PaintUtilsTest, GUI)
+QTEST_MAIN(PaintUtilsTest)
 
 void PaintUtilsTest::testScaledRect_data()
 {
